@@ -26,16 +26,6 @@ def are_all_elements_unique(elements):
     return True
 
 
-def write_files_to_list(files, alias, output_dir):
-    """Write the list of files to a path built from alias and output_dir."""
-    list_filename = os.path.join(output_dir, f"{alias}_files.list")
-    os.makedirs(os.path.dirname(list_filename), exist_ok=True)
-    with open(list_filename, "w") as handle:
-        for filename in files:
-            handle.write(filename + "\n")
-    return list_filename
-
-
 def get_valid_filename(s):
     """Return string with characters not allowed in filenames replaced by underscore."""
     return re.sub(r'[^-.0-9a-zA-Z]+', '_', s)
